@@ -10,22 +10,28 @@ class User(Base):
     surname = Column(String)
     fullname = Column(String)
     email = Column(String, unique=True, index=True)
-    list_banks = Column(ARRAY(PickleType), default=[])
+    list_banks = ARRAY(PickleType)
     hashed_password = Column(String)
     is_active = Column(Boolean, default=True)
 
-    identity = relationship("Identity", back_populates="user")
+    bank = relationship("Bank", back_populates="user")
 
     def to_json(self):
         return vars(self)
 
 
-class Identity(Base):
-    __tablename__ = "identity"
+class Bank(Base):
+    __tablename__ = "bank"
 
     id = Column(Integer, primary_key=True, index=True)
     balance = Column(Integer)
+    token = Column(String)
+    cpf = Column(String)
+    password = Column(String)
     user_id = Column(Integer, ForeignKey("users.id"))
     is_active = Column(Boolean, default=True)
 
-    user = relationship("User", back_populates="identity")
+    user = relationship("User", back_populates="bank")
+
+    def to_json(self):
+        return vars(self)
